@@ -3,7 +3,6 @@ import numpy as np
 import json
 
 
-
 class Cleaner:
     """ Module that helps to clean and arrange raw data"""
 
@@ -40,12 +39,9 @@ class Cleaner:
         # log file for documentation
         log_file = pd.DataFrame(log_file, columns=['Number_of_canceled_Orders', 'Number_of_free_orders',
                                                    'Number_of_missing_customers_info'])
+        return df_3, log_file
 
-        display(log_file)
-
-        return df_3
-
-    def getshippingprice(self,df):
+    def getshippingprice(self, df):
         """
 
         """
@@ -53,7 +49,7 @@ class Cleaner:
 
         return df
 
-    def getshippingpricevalue(self,x):
+    def getshippingpricevalue(self, x):
         if len(x) > 1:
             try:
                 value = json.loads(x)
@@ -68,7 +64,3 @@ class Cleaner:
             shipping_price = 0
 
         return shipping_price
-
-
-
-
