@@ -139,8 +139,8 @@ class Crp:
         """
 
         # Type modification for query execution
-        dateFlag_sep = str(dateFlag_sep)
-        date_flag_min = str(date_flag_min)
+        dateFlag_sep = str(dateFlag_sep.date())
+        date_flag_min = str(date_flag_min.date())
 
         # Map the relevant values according to the primary key
         target = train_df[train_df.customerid.map(matrix['createdat']) == train_df.createdat][['customerid',
@@ -233,15 +233,12 @@ class Crp:
 
         df_matrix = grp.agg(grp_dict).rename(columns={'id': 'num_orders', 'totalprice': 'TotalSpent'})
         # Create only date column
-        print(df_matrix.shape)
         df_matrix['order_date'] = df_matrix['createdat'].dt.date
 
         # Recency Feature
         df_matrix = self.getRecency(df_matrix, dateFlag_sep)
-        print(df_matrix.shape)
         # Different Last orders parameters feature ( Discount value, weight )
         df_matrix = self.getLastOrderparams(df_matrix, train_df, dateFlag_sep, date_flag_min, customer_name, sq_pass)
-        print(df_matrix.shape)
         df_matrix = self.getTotalSpentLMonth(train_df, dateFlag_sep, df_matrix, lastTimeflagParam)
 
         # Turn the separators into strings for the snowflake query
@@ -253,7 +250,6 @@ class Crp:
         orders_param.columns = orders_param.columns.str.lower()
 
         output = pd.merge(df_matrix, orders_param, how='left', on='customerid')
-        print(output.shape)
         output = output.fillna(999)
 
         return output
@@ -280,9 +276,9 @@ class Crp:
             original_dataset ->
             timeFlag         ->
             train_window     ->
-        -------------------------------__version__
+        -------------------------------
         Output:
-        :")
+
         """
 
         # Get the first matrices
